–accelerator=ACCELERATOR — Translate Toolkit 1.9.0 documentation

Translate Toolkit 1.9.0

- Site
  - Features
  - Installation
  - Converters
  - Tools
  - Scripts
  - Use Cases
  - Supported formats
  - Translate Styleguide
  - Documentation
  - Building
  - Contributing
  - Translate Toolkit Developers Guide
  - API
  - Important Changes
  - History of the Translate Toolkit
  - License
- Page
  - –accelerator=ACCELERATOR
- « –personality=TYPE
- poconflicts »

# –accelerator=ACCELERATOR

Accelerator Marker | Used by
--- | ---
& | KDE Desktop and Mozilla (when using moz2po)
_ | GNOME Desktop and other GTK+ based applications
~ | LibreOffice and Apache OpenOffice